package jdk.javadoc.internal.tool.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "17.0.4.1+1" },
            { "jdk", "17.0.4.1" },
            { "release", "17.0.4.1" },
        };
    }
}
